@@ -1,4 +1,4 @@
-package Pcore::PDF v0.3.1;
+package Pcore::PDF v0.3.2;
 
 use Pcore -dist, -class, -const, -result;
 use Config;
@@ -378,14 +378,61 @@ Pcore::PDF - HTML to PDF convertor
 
 =head1 SYNOPSIS
 
+    use Pcore::PDF;
+
+    my $pdf = Pcore::PDF->new({
+        prince      => 'path-to-princexml-executable',
+        max_threads => 4,
+    });
+
+    my $cv = AE::cv;
+
+    $pdf->generate_pdf($html, sub ($res) {
+        if (!$res) {
+            say $res;
+        }
+        else {
+
+            # $res->{data}->{pdf} contains ScalarRef to generated PDF content
+        }
+
+        return;
+    });
+
+    $cv->recv;
+
 =head1 DESCRIPTION
 
+Generate PDF from HTML templates, using princexml.
+
 =head1 ATTRIBUTES
 
+=over
+
+=item prince
+
+Path to princexml executable. Mandatory attribute.
+
+=item max_threads
+
+Maximum number of princexml processes. Under Windows this value should be 1, under linux default value is 4.
+
+=back
+
 =head1 METHODS
 
+=over
+
+=item generate_pdf( $self, $html, $cb )
+
+Generates PDF from $html template.
+
+=back
+
 =head1 SEE ALSO
 
+L<https://www.princexml.com/|https://www.princexml.com/>
+
 =head1 AUTHOR
 
 zdm <zdm@softvisio.net>
